@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Dist::Zilla;
 
@@ -349,7 +349,6 @@ sub _build_plugins {
         qw(
             PodSyntaxTests
             Test::CPAN::Changes
-            Test::Compile
             Test::EOL
             Test::NoTabs
             Test::Portability
@@ -357,6 +356,7 @@ sub _build_plugins {
             Test::TidyAll
             Test::Version
             ),
+        [ 'Test::Compile' => { xt_mode => 1 } ],
 
         # from @Git - note that the order here is important!
         [ 'Git::Check' => { allow_dirty => \@allow_dirty }, ],
@@ -440,7 +440,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MaxMind's plugin bundle
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =for Pod::Coverage .*
 
